==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/languages/spanish/homesite-info.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$HR001="Editado por &uacute;ltima vez: ";
$HR002="por";

// Info Botton
$IB001="Editar";
$IB002="Borrar";

// Info Edition Messages (IEM)
$IEM001="Fecha de Edici&oacute;n:";
$IEM002="Titular";
$IEM003="Texto";
$TEXT008="Si env&iacute;as como HTML, entonces las etiquetas ser&aacute;n interpretadas";
$TEXT009="Enviar como:";
$TEXT010="Texto plano";
$TEXT011="HTML";

$IEM005="Esta es la lista actual de fotos para esta informaci&oacute;n.<br>".
        "Puedes seleccionar una o m&aacute;s para ser borradas.<br>Por otro lado,".
        " si deseas a&ntilde;adir otra imagen a esta informaci&oacute;n, ".
        "entonces seleccionala con la opci&oacute;n Adjuntar Foto.";

$IEM006="Adjuntar Foto:";

// Photo Table Editon Messages (PTEM)

$PTEM001="Borrar";
$PTEM002="Nombre de archivo";
$PTEM003="Id. Foto";
$PTEM004="Foto en miniatura";
 
// Info Edition Boton Messages (IEEBM)

$IEBM001="Previsualizar";
$IEBM002="Publicar";  // See homesite-includes-dbwa.pnp before translate this

// Info Deleting Messages (IDM)

$IDM001="Fecha de Borrado:";

$IDM002="Todos los datos se perder&aacute;n y ser&aacute;n reemplazados por ".
        "las opciones por defecto, si continuas.<br><br>Asegurate antes de continuar !!!";

$IDM003="Si no deseas mostrar mas esta secci&oacute;n, ".
        "entonces deber&aacute;s editar la fichero de configuraci%oacute;n del sitio web.";

// Info Deleting Boton Messages (IDBM)

$IDBM001="Borrar";

// Info Edition Alert Messages

$ALERT001="Secci&oacute;n Vac&iacute;a !<br>".
          "Quiz&aacute;s quieras a&ntilde;adir algo de informaci&oacute;n aqu&iacute;.<br>".
          "De lo contrario, deberias eliminar esta secci&oacute;n.";

?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/languages/spanish/homesite-info.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


//---------- ./homesite/info.php ----------

// Headline Row (HR)
$HR001="Editado por &uacute;ltima vez: ";
$HR002="por";

// Info Botton
$IB000="Editar (GUI)";
$IB001="Editar (texto)";
$IB002="Borrar";

// Info Edition Messages (IEM)
$IEM001="Fecha de Edici&oacute;n:";
$IEM002="Titular";
$IEM003="Texto";
$TEXT008="Si env&iacute;as como HTML, entonces las etiquetas ser&aacute;n interpretadas";
$TEXT009="Enviar como:";
$TEXT010="Texto plano";
$TEXT011="HTML";
$TEXT012="Si no ves la barra de edici&oacute;n, es porque tu navegador no soporta esta caracter&iacute;stica.<br>".
         "Utiliza la opci&oacute;n 'Editar (texto)' o utiliza uno de estos novegadores:<br>".
         "IE 5.5+ (Windows), Firefox 1.0+, Mozilla 1.3+ and Netscape 7+";

$IEM005="Esta es la lista actual de fotos para esta informaci&oacute;n.<br>".
        "Puedes seleccionar una o m&aacute;s para ser borradas.<br>Por otro lado,".
        " si deseas a&ntilde;adir otra imagen a esta informaci&oacute;n, ".
        "entonces seleccionala con la opci&oacute;n Adjuntar Foto.";

$IEM006="Adjuntar Foto:";

// Photo Table Editon Messages (PTEM)

$PTEM001="Borrar";
$PTEM002="Nombre de archivo";
$PTEM003="Id. Foto";
$PTEM004="Foto en miniatura";
 
// Info Edition Boton Messages (IEEBM)

$IEBM001="Previsualizar";
$IEBM002="Publicar";  // See homesite-includes-dbwa.pnp before translate this

// Info Deleting Messages (IDM)

$IDM001="Fecha de Borrado:";

$IDM002="Todos los datos se perder&aacute;n y ser&aacute;n reemplazados por ".
        "las opciones por defecto, si continuas.<br><br>Asegurate antes de continuar !!!";

$IDM003="Si no deseas mostrar mas esta secci&oacute;n, ".
        "entonces deber&aacute;s editar la fichero de configuraci%oacute;n del sitio web.";

// Info Deleting Boton Messages (IDBM)

$IDBM001="Borrar";

// Info Edition Alert Messages

$ALERT001="Secci&oacute;n Vac&iacute;a !<br>".
          "Quiz&aacute;s quieras a&ntilde;adir algo de informaci&oacute;n aqu&iacute;.<br>".
          "De lo contrario, deberias eliminar esta secci&oacute;n.";

?>
